/*

DSN PLL v.1 - ATTINY, FOR 2.3GHz TRANSVERTER
   YO4HFU 28.05.2022

  Registers ADF4106; I > F > R > N
  Register F header (C1,C2) = (1,1), Function Latch converted to Initialization;

  PLL 1690...2310MHz (DSN-2300), 500KHz PD, 5mA...better phase noise
 
*/

////////////////// 2300MHz, FI 144MHz ////////////////////////
const unsigned long I_REG_0 = 0x9F8013; // 
const unsigned long F_REG_0 = 0x9F8012; // 5mA, PD-
const unsigned long R_REG_0 = 0x50; // PDF=500KHz
const unsigned long N_REG_0 = 0x8661; // 2156MHz

////////////////// 2304MHz, FI 144MHz ////////////////////////
const unsigned long I_REG_1 = 0x9F8013; // 
const unsigned long F_REG_1 = 0x9F8012; // 5mA, PD-
const unsigned long R_REG_1 = 0x50; // PDF=500KHz
const unsigned long N_REG_1 = 0x8701; // 2160MHz

////////////////// 2320MHz, FI 144MHz ////////////////////////
const unsigned long I_REG_2 = 0x9F8013; // 
const unsigned long F_REG_2 = 0x9F8012; // 5mA, PD-
const unsigned long R_REG_2 = 0x50; // PDF=500KHz
const unsigned long N_REG_2 = 0x8801; // 2176MHz

////////////////// 2400MHz, FI 144MHz ////////////////////////
const unsigned long I_REG_3 = 0x9F8013; // 
const unsigned long F_REG_3 = 0x9F8012; // 5mA, PD-
const unsigned long R_REG_3 = 0x50; // PDF=500KHz
const unsigned long N_REG_3 = 0x8D01; // 2256MHz


int bp;
int J1 = 0; //variable for reading the Switch J1
int J2 = 0; //variable for reading the Switch J2
unsigned long DTA_0;


///////////////// ARDUINO PINOUT ////////////////////////

const int LE_0 = 0;    // latch 
const int DATA = 2;    // DATA
const int CLK = 1;     // CLK

const int J1pin = 3;     // CLK
const int J2pin = 4;     // CLK


void setup() {

  pinMode (J1pin, INPUT_PULLUP); //switch input
  pinMode (J2pin, INPUT_PULLUP); //switch input
  pinMode (CLK, OUTPUT);     // clock
  pinMode (LE_0, OUTPUT);    // latch 
  pinMode (DATA, OUTPUT);    // data
  digitalWrite(CLK, LOW);    // clear CLK line
  digitalWrite(LE_0, HIGH);  // clear LE line

 J1 = digitalRead(J1pin); //Read Switch input
 J2 = digitalRead(J2pin); //Read Switch input
  
 delay (200);


if (J2==LOW && J1==LOW) 
 {
    DTA_0 = I_REG_0; // first sent
    SendWord_0();
    DTA_0 = F_REG_0; // 
    SendWord_0();
    DTA_0 = R_REG_0;
    SendWord_0();
    DTA_0 = N_REG_0;
    SendWord_0();
 }


if (J2==LOW && J1==HIGH)
{
    DTA_0 = I_REG_1; // first sent
    SendWord_0();
    DTA_0 = F_REG_1; // 
    SendWord_0();
    DTA_0 = R_REG_1;
    SendWord_0();
    DTA_0 = N_REG_1;
    SendWord_0();
 }


if (J2==HIGH && J1==LOW)
 {
    DTA_0 = I_REG_2; // first sent
    SendWord_0();
    DTA_0 = F_REG_2; // 
    SendWord_0();
    DTA_0 = R_REG_2;
    SendWord_0();
    DTA_0 = N_REG_2;
    SendWord_0();
 }


if (J2==HIGH && J1==HIGH)
 {
    DTA_0 = I_REG_3; // first sent
    SendWord_0();
    DTA_0 = F_REG_3; // 
    SendWord_0();
    DTA_0 = R_REG_3;
    SendWord_0();
    DTA_0 = N_REG_3;
    SendWord_0();
 }
 
}


void loop() { } // loop closed

int SendWord_0() {
  bp = 24;
  do {
    bp = bp - 1; // loop through bit positions 24 to 0
    digitalWrite(CLK, LOW);
    digitalWrite(LE_0, LOW);
    digitalWrite(DATA, bitRead(DTA_0, bp) );
    digitalWrite(CLK, HIGH);
  }
  while (bp > 0);
  digitalWrite(CLK, LOW);
  digitalWrite(DATA, LOW);
  digitalWrite(LE_0, HIGH);  // Set LE to latch data
  delayMicroseconds (100);  // LE pulse
}
